@@ -1,5 +1,5 @@
 package Cache::Bounded;
-$Cache::Bounded::VERSION='1.08';
+$Cache::Bounded::VERSION='1.09';
 
 use warnings;
 use strict;
@@ -40,8 +40,9 @@ sub set {
   my $data = shift @_;
   $self->{count}++;
 
-  if ( $self->{count} > $self->{interval} && scalar(keys %{$self->{cache}}) > $self->{size}) {
-    $self->purge();
+  if ( $self->{count} >= $self->{interval} ) {
+    $self->{count} = 0;
+    $self->purge() if (scalar(keys %{$self->{cache}})+1) >= $self->{size};
   }
 
   $self->{cache}->{$key} = $data;
@@ -78,7 +79,7 @@ Additionally, to aid speed, the "size" check doesn't occur on every
 insertion. Only after a count of a certain number of insertions (default
 1,000) is the size check performed. If the size limit has been exceeded,
 the entire cache is purged. (Since there is no usage analysis, there is no
-other logical depreciation that can be applied)
+other logical depreciation that can be applied.)
 
 This produces a very fast in-memory cache that you can tune to approximate
 size based upon your data elements.
@@ -163,11 +164,11 @@ Use scalar data.
 
 =head1 VERSION
 
-    Cache::Bounded v1.08 (2014/03/10)
+    Cache::Bounded v1.09 (2015/06/18)
 
 =head1 COPYRIGHT
 
-    (c) 2004-2014, Phillip Pollard <bennie@cpan.org>
+    (c) 2004-2015, Phillip Pollard <bennie@cpan.org>
 
 =head1 LICENSE
 
